==> Paws-0.15.tar.gz: Paws-0.15/lib/Paws/CloudWatchLogs/DeleteDestination.pm <==

package Paws::CloudWatchLogs::DeleteDestination;
  use Moose;
  has destinationName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteDestination');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchLogs::DeleteDestination - Arguments for method DeleteDestination on Paws::CloudWatchLogs

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteDestination on the 
Amazon CloudWatch Logs service. Use the attributes of this class
as arguments to method DeleteDestination.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DeleteDestination.

As an example:

  $service_obj->DeleteDestination(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> destinationName => Str

  

The name of destination to delete.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteDestination in L<Paws::CloudWatchLogs>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.17.tar.gz: Paws-0.17/lib/Paws/CloudWatchLogs/DeleteDestination.pm <==

package Paws::CloudWatchLogs::DeleteDestination;
  use Moose;
  has DestinationName => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'destinationName' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteDestination');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchLogs::DeleteDestination - Arguments for method DeleteDestination on Paws::CloudWatchLogs

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteDestination on the 
Amazon CloudWatch Logs service. Use the attributes of this class
as arguments to method DeleteDestination.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteDestination.

As an example:

  $service_obj->DeleteDestination(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> DestinationName => Str

  The name of destination to delete.



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteDestination in L<Paws::CloudWatchLogs>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
